Nyk.SimpleArithmeticLib 0.1.0

Edit this page

Say Module

Initial module

Types

Type Description

FavoriteColor

Finite list of Colors

Person

A person with many different field types

Functions and values

Function or value Description

add a b

Full Usage: add a b

Parameters:
    a : int - An integer.
    b : int - An integer.

Returns: int The sum of two integers.

Adds two integers a and b and returns the result.

This usually contains some really important information that you'll miss if you don't read the docs.

a : int

An integer.

b : int

An integer.

Returns: int

The sum of two integers.

helloPerson person

Full Usage: helloPerson person

Parameters:
Returns: string

Says hello to a specific person

person : Person
Returns: string

nothing name

Full Usage: nothing name

Parameters:
    name : 'a

I do nothing

name : 'a